import { ITopFilter } from '@/pages/TaskManage/Detail/TaskList/taskList.types';
import { CaretDownFilled, CloseCircleFilled } from '@ant-design/icons';
import { Col, Row, Select } from 'antd';

import { useState } from 'react';
import '../index.less';

interface IProps {
  filters: ITopFilter[];
  onChange: (value: any) => void;
}

const TopFilter: React.FC<IProps> = ({ filters, onChange }) => {
  const [values, setValues] = useState<any[]>(
    new Array(filters.length).fill(undefined),
  );

  return (
    <Row justify="space-around" style={{ marginTop: '30px' }}>
      {filters.map((item, index) => {
        return (
          <Col
            key={item.key}
            span={Math.floor(22 / filters.length)}
            style={{ textAlign: 'center' }}
          >
            <Select
              className="antdSelect"
              size="large"
              bordered={false}
              placeholder={item.placeholder}
              options={item.options}
              popupMatchSelectWidth={250}
              suffixIcon={
                values[index]===null || values[index]===undefined ? (
                  <CaretDownFilled
                    style={{
                      fontSize: '28px',
                      color: 'black',
                    }}
                  />
                ) : null
              }
              clearIcon={
                <CloseCircleFilled
                  style={{
                    fontSize: '28px',
                    color: 'black',
                    paddingBottom: '20px',
                  }}
                />
              }
              allowClear
              onChange={(value) => {
                const temp = filters.map((f, i) => {
                  if (index === i) {
                    return value !== undefined ? value : null;
                  }
                  return values[i] || null;
                });
                setValues(temp);
                onChange(temp);
              }}
              onClear={() => {
                const temp = filters.map((f, i) => {
                  if (index === i) {
                    return null;
                  }
                  return values[i];
                });
                setValues(temp);
                onChange(temp);
              }}
            />
          </Col>
        );
      })}
    </Row>
  );
};

export default TopFilter;
